@@ -9,6 +9,8 @@
  * GNU General Public License for more details.
  */
 
+/* DON'T CHANGE THESE SETTINGS !!
+ */
 #ifndef _GLOBAL_H
 #define _GLOBAL_H
 
@@ -20,6 +22,10 @@
 #define HOUR    3600
 #define DAY    86400
 
+#define PTHREAD_STACK_SIZE 512 * KILOBYTE
+
+#define TASK_RUNNER_INTERVAL 10
+
 #define TIMER_OFF -1
 
 #endif
