@@ -934,7 +934,7 @@ int serve_client(t_session *session) {
 #ifdef HAVE_TOOLKIT
 	/* URL toolkit
 	 */
-	init_toolkit_options(&options, session->host->website_root, session->config->url_toolkit);
+	init_toolkit_options(&options, session->host->website_root, session->config->url_toolkit, session->binding->use_ssl);
 
 	if ((session->request_method != PUT) && (session->request_method != DELETE)) {
 		for (i = 0; i < session->host->toolkit_rules.size; i++) {
@@ -1367,6 +1367,7 @@ void connection_handler(t_session *session) {
 		close_socket(session);
 	} else {
 		close(session->client_socket);
+		session->socket_open = false;
 	}
 
 #ifdef HAVE_MONITOR
@@ -1725,7 +1726,9 @@ int accept_connection(t_binding *binding, t_config *config) {
 		}
 	} else switch (total_conns) {
 		case ca_TOOMUCH_PERIP:
+			log_system(session, "Maximum number of connections for IP address reached");
 			if ((config->ban_on_max_per_ip > 0) && ip_allowed(&(session->ip_address), session->config->banlist_mask)) {
+				log_system(session, "Client banned because of too many simultaneous connections");
 				ban_ip(&(session->ip_address), config->ban_on_max_per_ip, config->kick_on_ban);
 #ifdef HAVE_MONITOR
 				if (config->monitor_enabled) {
@@ -1733,7 +1736,6 @@ int accept_connection(t_binding *binding, t_config *config) {
 				}
 #endif
 			}
-			log_system(session, "Maximum number of connections for IP address reached");
 			break;
 		case ca_TOOMUCH_TOTAL:
 			log_system(session, "Maximum number of total connections reached");
@@ -1891,17 +1893,21 @@ int run_server(t_settings *settings) {
 		if (errno != EEXIST) {
 			fprintf(stderr, "Error creating work directory '%s'\n", config->work_directory);
 			return -1;
+#ifndef CYGWIN
 		} else if (chmod(config->work_directory, 0700) == -1) {
 			fprintf(stderr, "Can't change access permissions of work directory '%s'\n", config->work_directory);
 			return -1;
+#endif
 		}
 	}
+#ifndef CYGWIN
 	if ((getuid() == 0) || (geteuid() == 0)) {
 		if (chown(config->work_directory, config->server_uid, config->server_gid) == -1) {
 			perror("chown(WorkDirectory)");
 			return -1;
 		}
 	}
+#endif
 
 	/* Create the upload directory for PUT requests
 	 */
@@ -1912,6 +1918,7 @@ int run_server(t_settings *settings) {
 		}
 	}
 
+#ifndef CYGWIN
 	if (stat(config->upload_directory, &status) == -1) {
 		perror("stat(UploadDirectory)");
 		return -1;
@@ -1934,6 +1941,7 @@ int run_server(t_settings *settings) {
 			return -1;
 		}
 	}
+#endif
 
 #ifdef HAVE_MONITOR
 	/* Create monitor cache directory
@@ -1942,17 +1950,21 @@ int run_server(t_settings *settings) {
 		if (errno != EEXIST) {
 			fprintf(stderr, "Error creating monitor directory '%s'\n", config->monitor_directory);
 			return -1;
+#ifndef CYGWIN
 		} else if (chmod(config->monitor_directory, 0700) == -1) {
 			fprintf(stderr, "Can't change access permissions of monitor directory '%s'\n", config->monitor_directory);
 			return -1;
+#endif
 		}
 	}
+#ifndef CYGWIN
 	if ((getuid() == 0) || (geteuid() == 0)) {
 		if (chown(config->monitor_directory, config->server_uid, config->server_gid) == -1) {
 			perror("chown(MonitorDirectory)");
 			return -1;
 		}
 	}
+#endif
 #endif
 
 	/* Create logfiles
@@ -1960,11 +1972,12 @@ int run_server(t_settings *settings) {
 #ifdef HAVE_CHROOT
 	touch_logfiles(config, config->server_root);
 #else
-	touch_logfiles(config, "/");
+	touch_logfiles(config, "");
 #endif
 
 	/* Change userid
 	 */
+#ifndef CYGWIN
 	if ((getuid() == 0) || (geteuid() == 0)) do {
 		if (setgroups(config->groups.number, config->groups.array) != -1) {
 			if (setgid(config->server_gid) != -1) {
@@ -1976,6 +1989,7 @@ int run_server(t_settings *settings) {
 		fprintf(stderr, "\nError while changing uid/gid!\n");
 		return -1;
 	} while (false);
+#endif
 
 	if (settings->daemon == false) {
 		printf("Press Ctrl-C to shutdown the Hiawatha webserver.\n");
