@@ -34,7 +34,7 @@
 bool group_oke(t_session *session, char *user, t_charlist *group) {
 	bool retval;
 	FILE *gfp;
-	char *pwfile, line[257], *item, *rest, *result;
+	char line[257], *item, *rest, *result;
 	int len;
 
 	if ((user == NULL) || (group->size == 0)) {
@@ -44,8 +44,7 @@ bool group_oke(t_session *session, char *user, t_charlist *group) {
 		return false;
 	}
 
-	pwfile = file_in_chroot(session, session->host->groupfile);
-	if ((gfp = fopen_neighbour(pwfile, "r", session->file_on_disk)) == NULL) {
+	if ((gfp = fopen_neighbour(session->host->groupfile, "r", session->file_on_disk)) == NULL) {
 		switch (errno) {
 			case EACCES:
 				result = "no access to group file";
@@ -92,11 +91,10 @@ bool group_oke(t_session *session, char *user, t_charlist *group) {
 /* Read a password from a file
  */
 static char *get_password(t_session *session, char *username) {
-	char *pwfile, line[257], *result = NULL, *sep;
+	char line[257], *result = NULL, *sep;
 	FILE *pfp;
 	
-	pwfile = file_in_chroot(session, session->host->passwordfile);
-	if ((pfp = fopen_neighbour(pwfile, "r", session->file_on_disk)) == NULL) {
+	if ((pfp = fopen_neighbour(session->host->passwordfile, "r", session->file_on_disk)) == NULL) {
 		switch (errno) {
 			case EACCES:
 				result = "no access to password file";
