@@ -1,3 +1,14 @@
+/* This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License. For a copy,
+ * see http://www.gnu.org/licenses/gpl-2.0.html.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ */
+
 #include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
@@ -336,6 +347,40 @@ t_access ip_allowed(t_ip_addr *ip, t_accesslist *list) {
 	return unspecified;
 }
 
+/*---< ip list >-------------------------------------------------------------*/
+
+int parse_iplist(char *line, t_iplist **list) {
+	char *proxy;
+	t_iplist *new;
+	
+	while (line != NULL) {
+		split_string(line, &proxy, &line, ',');
+
+		if ((new = (t_iplist*)malloc(sizeof(t_iplist))) == NULL) {
+			return -1;
+		}
+		new->next = *list;
+		*list = new;
+
+		if (parse_ip(proxy, &(new->ip)) == -1) {
+			return -1;
+		}
+	}
+
+	return 0;
+}
+
+bool in_iplist(t_iplist *list, t_ip_addr *ip) {
+	while (list != NULL) {
+		if (same_ip(&(list->ip), ip)) {
+			return true;
+		}
+		list = list->next;
+	}
+	
+	return false;
+}
+
 /*---< key/valuelist >-------------------------------------------------------*/
 
 /* Parse a list of key/value combinations.
