@@ -21,13 +21,13 @@
 #include <pthread.h>
 #include "global.h"
 #include "liblist.h"
+#include "libip.h"
 #include "log.h"
 
 #define BUFFER_SIZE        2 * KILOBYTE
 #define TIMESTAMP_SIZE    40
-#define IP_ADDRESS_SIZE   MAX_IP_STR_LEN + 2
+#define IP_ADDRESS_SIZE   MAX_IP_STR_LEN + 1
 
-#define MAX_LOG_DELAY_TIMER 10
 #define LOGFILE_OPEN_TIME   30
 
 #ifdef CYGWIN
@@ -37,11 +37,9 @@
 #endif
 
 pthread_mutex_t accesslog_mutex;
-static int delay_timer = 0;
 
 void init_log_module(void) {
 	pthread_mutex_init(&accesslog_mutex, NULL);
-	delay_timer = 0;
 }
 
 /* Write a timestamp to a logfile.
@@ -56,16 +54,6 @@ static void print_timestamp(char *str) {
 	strftime(str, TIMESTAMP_SIZE - 1, "%a %d %b %Y %T %z|", s);
 }
 
-/* Write an IP address to a logfile.
- */
-static void print_ip_address(char *str, t_ip_addr *ip) {
-	if (inet_ntop(ip->family, &(ip->value), str, IP_ADDRESS_SIZE) == NULL) {
-		strcpy(str, "?.?.?.?|");
-	} else {
-		strcat(str, "|");
-	}
-}
-
 static char *secure_string(char *str) {
 	char *c = str;
 
@@ -95,12 +83,14 @@ void log_pid(t_config *config, pid_t pid) {
 
 	fprintf(fp, "%d\n", (int)pid);
 	fclose(fp);
+#ifndef CYGWIN
 	if (chmod(config->pidfile, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH) == -1) {
 		fprintf(stderr, "Warning: can't chmod PID file %s. Make sure it's only writable for root!\n", config->pidfile);
 	}
 	if (chown(config->pidfile, 0, 0) == -1) {
 		fprintf(stderr, "Warning: can't chown PID file %s. Make sure it's owned by root!\n", config->pidfile);
 	}
+#endif
 }
 
 /* Log a text.
@@ -139,7 +129,8 @@ void log_system(t_session *session, char *mesg) {
 		return;
 	}
 
-	print_ip_address(str, &(session->ip_address));
+	ip_to_str(str, &(session->ip_address), IP_ADDRESS_SIZE);
+	strcat(str, "|");
 	print_timestamp(str + strlen(str));
 	fprintf(fp, "%s%s\n", str, mesg);
 	fclose(fp);
@@ -158,12 +149,8 @@ void log_file_error(t_session *session, char *file, char *mesg) {
 	}
 
 	print_timestamp(str);
-	print_ip_address(str + strlen(str), &(session->ip_address));
-	if (file != NULL) {
-		fprintf(fp, "%s%s|%s"EOL, str, file, mesg);
-	} else {
-		fprintf(fp, "%s-|%s"EOL, str, mesg);
-	}
+	ip_to_str(str + strlen(str), &(session->ip_address), IP_ADDRESS_SIZE);
+	fprintf(fp, "%s|%s|%s"EOL, str, file, mesg);
 	fclose(fp);
 }
 
@@ -210,7 +197,8 @@ void log_request(t_session *session, int code) {
 	if (session->config->log_format == hiawatha) {
 		/* Hiawatha log format
 		 */
-		print_ip_address(str, &(session->ip_address));
+		ip_to_str(str, &(session->ip_address), IP_ADDRESS_SIZE);
+		strcat(str, "|");
 		offset = strlen(str);
 		print_timestamp(str + offset);
 		offset += strlen(str + offset);
@@ -251,7 +239,8 @@ void log_request(t_session *session, int code) {
 	} else {
 		/* Common Log Format
 		 */
-		print_ip_address(ip_address, &(session->ip_address));
+		ip_to_str(ip_address, &(session->ip_address), IP_ADDRESS_SIZE);
+		strcat(ip_address, "|");
 		if ((len = strlen(ip_address)) > 0) {
 			ip_address[len - 1] = '\0';
 		}
@@ -338,7 +327,8 @@ void log_garbage(t_session *session) {
 		return;
 	}
 
-	print_ip_address(str, &(session->ip_address));
+	ip_to_str(str, &(session->ip_address), IP_ADDRESS_SIZE);
+	strcat(str, "|");
 	print_timestamp(str + strlen(str));
 	fprintf(fp, "%s%s"EOL, str, session->request);
 	fclose(fp);
@@ -359,7 +349,8 @@ void log_exploit_attempt(t_session *session, char *type, char *data) {
 	host = (session->host->hostname.size > 0) ? session->host->hostname.item[0] : unknown;
 	uri = (session->uri != NULL) ? session->uri : unknown;
 
-	print_ip_address(str, &(session->ip_address));
+	ip_to_str(str, &(session->ip_address), IP_ADDRESS_SIZE);
+	strcat(str, "|");
 	print_timestamp(str + strlen(str));
 	fprintf(fp, "%s%s%s|%s|%s"EOL, str, host, uri, type, data);
 	fclose(fp);
@@ -377,7 +368,8 @@ void log_unban(char *logfile, t_ip_addr *ip_address, unsigned long connect_attem
 		return;
 	}
 
-	print_ip_address(str, ip_address);
+	ip_to_str(str, ip_address, IP_ADDRESS_SIZE);
+	strcat(str, "|");
 	print_timestamp(str + strlen(str));
 	fprintf(fp, "%sUnbanned (%ld connect attempts during ban)\n", str, connect_attempts);
 	fclose(fp);
@@ -411,11 +403,11 @@ void log_cgi_error(t_session *session, char *mesg) {
 	if (len > 0) {
 		if ((fp = fopen(session->host->error_logfile, "a")) != NULL) {
 			print_timestamp(str);
-			print_ip_address(str + strlen(str), &(session->ip_address));
+			ip_to_str(str + strlen(str), &(session->ip_address), IP_ADDRESS_SIZE);
 			if (session->file_on_disk == NULL) {
-				fprintf(fp, "%s-|%s"EOL, str, secure_string(mesg));
+				fprintf(fp, "%s|-|%s"EOL, str, secure_string(mesg));
 			} else {
-				fprintf(fp, "%s%s|%s"EOL, str, session->file_on_disk, secure_string(mesg));
+				fprintf(fp, "%s|%s|%s"EOL, str, session->file_on_disk, secure_string(mesg));
 			}
 			fclose(fp);
 		}
@@ -424,25 +416,18 @@ void log_cgi_error(t_session *session, char *mesg) {
 
 /* Close open access logfiles.
  */
-void close_logfiles(t_host *host, bool force_close) {
-	time_t now;
-
-	if ((++delay_timer >= MAX_LOG_DELAY_TIMER) || force_close) {
-		delay_timer = 0;
-		now = time(NULL);
-
-		pthread_mutex_lock(&accesslog_mutex);
-		while (host != NULL) {
-			if ((now >= host->access_time + LOGFILE_OPEN_TIME) || force_close) {
-				if (*(host->access_fp) != NULL) {
-					fclose(*(host->access_fp));
-					*(host->access_fp) = NULL;
+void close_logfiles(t_host *host, time_t now) {
+	pthread_mutex_lock(&accesslog_mutex);
+	while (host != NULL) {
+		if ((now >= host->access_time + LOGFILE_OPEN_TIME) || (now == 0)) {
+			if (*(host->access_fp) != NULL) {
+				fclose(*(host->access_fp));
+				*(host->access_fp) = NULL;
 				}
-			}
-			host = host->next;
 		}
-		pthread_mutex_unlock(&accesslog_mutex);
+		host = host->next;
 	}
+	pthread_mutex_unlock(&accesslog_mutex);
 }
 
 void close_logfiles_for_cgi_run(t_host *host) {
@@ -468,7 +453,8 @@ void log_debug(t_session *session, char *mesg, ...) {
 
 	va_start(args, mesg);
 
-	print_ip_address(str, &(session->ip_address));
+	ip_to_str(str, &(session->ip_address), IP_ADDRESS_SIZE);
+	strcat(str, "|");
 	print_timestamp(str + strlen(str));
 	fprintf(fp, "%s%05d|", str, session->thread_id);
 	vfprintf(fp, mesg, args);
