@@ -917,7 +917,7 @@ static bool system_setting(char *key, char *value, t_config *config) {
 		}
 #endif
 	} else if (strcmp(key, "reconnectdelay") == 0) {
-		if ((config->reconnect_delay = str2int(value)) != -1) {
+		if ((config->reconnect_delay = str2int(value)) > 0) {
 			return true;
 		}
 	} else if (strcmp(key, "serverid") == 0) {
